@@ -24,6 +24,99 @@ logger = logging.getLogger(__name__)
 
 
 class SnowflakeDialect(Dialect):
+    reserved_keywords = [
+        "ACCOUNT",
+        "ALL",
+        "ALTER",
+        "AND",
+        "ANY",
+        "AS",
+        "BETWEEN",
+        "BY",
+        "CASE",
+        "CAST",
+        "CHECK",
+        "COLUMN",
+        "CONNECT",
+        "CONNECTION",
+        "CONSTRAINT",
+        "CREATE",
+        "CROSS",
+        "CURRENT",
+        "CURRENT_DATE",
+        "CURRENT_TIME",
+        "CURRENT_TIMESTAMP",
+        "CURRENT_USER",
+        "DATABASE",
+        "DELETE",
+        "DISTINCT",
+        "DROP",
+        "ELSE",
+        "EXISTS",
+        "FALSE",
+        "FOLLOWING",
+        "FOR",
+        "FROM",
+        "FULL",
+        "GRANT",
+        "GROUP",
+        "GSCLUSTER",
+        "HAVING",
+        "ILIKE",
+        "IN",
+        "INCREMENT",
+        "INNER",
+        "INSERT",
+        "INTERSECT",
+        "INTO",
+        "IS",
+        "ISSUE",
+        "JOIN",
+        "LATERAL",
+        "LEFT",
+        "LIKE",
+        "LOCALTIME",
+        "LOCALTIMESTAMP",
+        "MINUS",
+        "NATURAL",
+        "NOT",
+        "NULL",
+        "OF",
+        "ON",
+        "OR",
+        "ORDER",
+        "ORGANIZATION",
+        "QUALIFY",
+        "REGEXP",
+        "REVOKE",
+        "RIGHT",
+        "RLIKE",
+        "ROW",
+        "ROWS",
+        "SAMPLE",
+        "SCHEMA",
+        "SELECT",
+        "SET",
+        "SOME",
+        "START",
+        "TABLE",
+        "TABLESAMPLE",
+        "THEN",
+        "TO",
+        "TRIGGER",
+        "TRUE",
+        "TRY_CAST",
+        "UNION",
+        "UNIQUE",
+        "UPDATE",
+        "USING",
+        "VALUES",
+        "VIEW",
+        "WHEN",
+        "WHENEVER",
+        "WHERE",
+        "WITH",
+    ]
 
     def __init__(self, parser: Parser):
         super().__init__(SNOWFLAKE)
@@ -172,12 +265,6 @@ class SnowflakeDialect(Dialect):
     def sql_expr_regexp_like(self, expr: str, pattern: str):
         return f"REGEXP_LIKE(COLLATE({expr}, ''), '{self.qualify_regex(pattern)}')"
 
-    def qualify_column_name(self, column_name: str, source_type: str = None):
-        return f'{column_name}'
-
-    def qualify_table_name(self, table_name: str) -> str:
-        return f'{table_name}'
-
     def is_connection_error(self, exception):
         if exception is None or exception.errno is None:
             return False
